# FT4FTIR

FT4FTIR (Fourier Tranform for Fourier Transform Infrared Spectroscopy) is a Python package for processing interferograms from FTIR (Fourier Transform Infrared Spectroscopy) data. 
It supports reading Bruker OPUS files, processing interferograms (apodization, zero-filling, Fourier transform), 
and extracting spectra for further analysis.

## Installation

You can install the package using `pip`:

```bash
pip install ft4ftir
